@define-color borders_breeze #565656;
@define-color content_view_bg_breeze #303030;
@define-color error_color_backdrop_breeze #da4453;
@define-color error_color_breeze #da4453;
@define-color error_color_insensitive_backdrop_breeze #663439;
@define-color error_color_insensitive_breeze #663439;
@define-color insensitive_base_color_breeze #2e2e2e;
@define-color insensitive_base_fg_color_breeze #686868;
@define-color insensitive_bg_color_breeze #262626;
@define-color insensitive_borders_breeze #353535;
@define-color insensitive_fg_color_breeze #636363;
@define-color insensitive_selected_bg_color_breeze #262626;
@define-color insensitive_selected_fg_color_breeze #636363;
@define-color insensitive_unfocused_bg_color_breeze #262626;
@define-color insensitive_unfocused_fg_color_breeze #636363;
@define-color insensitive_unfocused_selected_bg_color_breeze #262626;
@define-color insensitive_unfocused_selected_fg_color_breeze #636363;
@define-color link_color_breeze #4285f4;
@define-color link_visited_color_breeze #00bcd4;
@define-color success_color_backdrop_breeze #01a299;
@define-color success_color_breeze #01a299;
@define-color success_color_insensitive_backdrop_breeze #1e5451;
@define-color success_color_insensitive_breeze #1e5451;
@define-color theme_base_color_breeze #303030;
@define-color theme_bg_color_breeze #282828;
@define-color theme_button_background_backdrop_breeze #4d4d4d;
@define-color theme_button_background_backdrop_insensitive_breeze #494949;
@define-color theme_button_background_insensitive_breeze #494949;
@define-color theme_button_background_normal_breeze #4d4d4d;
@define-color theme_button_decoration_focus_backdrop_breeze #1e92ff;
@define-color theme_button_decoration_focus_backdrop_insensitive_breeze #3a6085;
@define-color theme_button_decoration_focus_breeze #1e92ff;
@define-color theme_button_decoration_focus_insensitive_breeze #3a6085;
@define-color theme_button_decoration_hover_backdrop_breeze #57b1ff;
@define-color theme_button_decoration_hover_backdrop_insensitive_breeze #4d6b85;
@define-color theme_button_decoration_hover_breeze #57b1ff;
@define-color theme_button_decoration_hover_insensitive_breeze #4d6b85;
@define-color theme_button_foreground_active_backdrop_breeze #dfdfdf;
@define-color theme_button_foreground_active_backdrop_insensitive_breeze #636363;
@define-color theme_button_foreground_active_breeze #ffffff;
@define-color theme_button_foreground_active_insensitive_breeze #636363;
@define-color theme_button_foreground_backdrop_breeze #dfdfdf;
@define-color theme_button_foreground_backdrop_insensitive_breeze #7a7a7a;
@define-color theme_button_foreground_insensitive_breeze #7a7a7a;
@define-color theme_button_foreground_normal_breeze #dfdfdf;
@define-color theme_fg_color_breeze #dfdfdf;
@define-color theme_header_background_backdrop_breeze #2a2a2a;
@define-color theme_header_background_breeze #2c2c2c;
@define-color theme_header_background_light_breeze #282828;
@define-color theme_header_foreground_backdrop_breeze #dfdfdf;
@define-color theme_header_foreground_breeze #dfdfdf;
@define-color theme_header_foreground_insensitive_backdrop_breeze #dfdfdf;
@define-color theme_header_foreground_insensitive_breeze #dfdfdf;
@define-color theme_hovering_selected_bg_color_breeze #83c9ff;
@define-color theme_selected_bg_color_breeze #1a73e8;
@define-color theme_selected_fg_color_breeze #ffffff;
@define-color theme_text_color_breeze #dfdfdf;
@define-color theme_titlebar_background_backdrop_breeze #2a2a2a;
@define-color theme_titlebar_background_breeze #2c2c2c;
@define-color theme_titlebar_background_light_breeze #282828;
@define-color theme_titlebar_foreground_backdrop_breeze #dfdfdf;
@define-color theme_titlebar_foreground_breeze #dfdfdf;
@define-color theme_titlebar_foreground_insensitive_backdrop_breeze #dfdfdf;
@define-color theme_titlebar_foreground_insensitive_breeze #dfdfdf;
@define-color theme_unfocused_base_color_breeze #303030;
@define-color theme_unfocused_bg_color_breeze #282828;
@define-color theme_unfocused_fg_color_breeze #dfdfdf;
@define-color theme_unfocused_selected_bg_color_alt_breeze #143868;
@define-color theme_unfocused_selected_bg_color_breeze #143868;
@define-color theme_unfocused_selected_fg_color_breeze #dfdfdf;
@define-color theme_unfocused_text_color_breeze #dfdfdf;
@define-color theme_unfocused_view_bg_color_breeze #2e2e2e;
@define-color theme_unfocused_view_text_color_breeze #686868;
@define-color theme_view_active_decoration_color_breeze #1e92ff;
@define-color theme_view_hover_decoration_color_breeze #1e92ff;
@define-color tooltip_background_breeze #282828;
@define-color tooltip_border_breeze #565656;
@define-color tooltip_text_breeze #dfdfdf;
@define-color unfocused_borders_breeze #565656;
@define-color unfocused_insensitive_borders_breeze #353535;
@define-color warning_color_backdrop_breeze #ff6d00;
@define-color warning_color_breeze #ff6d00;
@define-color warning_color_insensitive_backdrop_breeze #73421e;
@define-color warning_color_insensitive_breeze #73421e;
